/* This file is part of the KDE project
   Copyright (c) 2004 Cyrille Berger <cberger@cberger.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#include <stdlib.h>

#include <qpoint.h>

#include <klocale.h>
#include <kiconloader.h>
#include <kinstance.h>
#include <kmessagebox.h>
#include <kstandarddirs.h>
#include <ktempfile.h>
#include <kdebug.h>
#include <kgenericfactory.h>

#include <kis_doc.h>
#include <kis_image.h>
#include <kis_layer.h>
#include <kis_global.h>
#include <kis_types.h>
#include <kis_view.h>
#include <kistilemgr.h>

// #include <kmessagebox.h>

#include "example.moc"

typedef KGenericFactory<KritaExample> KritaExampleFactory;
K_EXPORT_COMPONENT_FACTORY( kritaexample, KritaExampleFactory( "kritaexample_plugin" ) )

KritaExample::KritaExample(QObject *parent, const char *name, const QStringList &)
    : KParts::Plugin(parent, name)
{
    setInstance(KritaExampleFactory::instance());

    (void) new KAction(i18n("&Example..."), SmallIcon("scanner"), 0, this, SLOT(slotActivated()), actionCollection(), "krita_example");
    if ( !parent->inherits("KisView") )
    {
        //kdError() << "KritaExempleFactory: KisView expected. Parent is " << parent->className() << endl;
        m_view = 0;
    } else {
      m_view = (KisView*) parent;
    }
}

KritaExample::~KritaExample()
{
}

void KritaExample::slotActivated()
{
  //KMessageBox::error(m_view, "woups", "wops");
  KisDoc* kD = (KisDoc*) m_view->koDocument();
  KisImageSP img; // = kD->currentImg();
  for( int nb = 0; ( img = kD->imageNum(nb) ) != 0 ; nb++)
  {
    KisTileMgrSP tilemgr = img->activeLayer()->data();
    QUANTUM* buffer = (QUANTUM*) malloc( tilemgr->width() * tilemgr->height() * tilemgr->depth() * sizeof(QUANTUM));
    tilemgr->readPixelData( 0, 0, tilemgr->width()-1, tilemgr->height()-1, buffer, tilemgr->depth() * tilemgr->width());
    for ( int i=0; i < tilemgr->width() * tilemgr->height() * tilemgr->depth(); i += 4)
    {
        buffer[i] = 255-buffer[i];
        buffer[i+1] = 255-buffer[i+1];
        buffer[i+2] = 255-buffer[i+2];
    }
    tilemgr->writePixelData( 0, 0, tilemgr->width()-1, tilemgr->height()-1, buffer, tilemgr->depth() * tilemgr->width());
    free(buffer);
    img->notify();
  }
}
